@@ -7,7 +7,9 @@ from applitools.common.selenium import Configuration
 from applitools.common.utils import argument_guard
 from applitools.common.utils.general_utils import all_fields, proxy_to
 from applitools.core.eyes_mixins import EyesConfigurationMixin
+from applitools.core.eyes_base import DebugScreenshotsAbstract
 from applitools.core.locators import VisualLocatorSettings, LOCATORS_TYPE
+from applitools.core.server_connector import ServerConnector
 from applitools.selenium import ClassicRunner, eyes_selenium_utils
 
 from .fluent import Target
@@ -38,7 +40,7 @@ if typing.TYPE_CHECKING:
 
 
 @proxy_to("configure", all_fields(Configuration))
-class Eyes(EyesConfigurationMixin):
+class Eyes(EyesConfigurationMixin, DebugScreenshotsAbstract):
     _is_visual_grid_eyes = False  # type: bool
     _visual_grid_eyes = None  # type: VisualGridEyes
     _selenium_eyes = None  # type: SeleniumEyes
@@ -83,6 +85,17 @@ class Eyes(EyesConfigurationMixin):
         # type:(Configuration) -> None
         return super(Eyes, self).set_configuration(configuration)
 
+    @property
+    def server_connector(self):
+        # type: () -> ServerConnector
+        return self._current_eyes.server_connector
+
+    @server_connector.setter
+    def server_connector(self, server_connector):
+        # type: (ServerConnector) -> None
+        argument_guard.is_a(server_connector, ServerConnector)
+        self._current_eyes.server_connector = server_connector
+
     @property
     def configure(self):
         # type:() -> Configuration
@@ -191,17 +204,44 @@ class Eyes(EyesConfigurationMixin):
         return None
 
     @property
-    def _debug_screenshot_provided(self):
+    def save_debug_screenshots(self):
         # type: () -> bool
         """True if screenshots saving enabled."""
-        if not self._is_visual_grid_eyes:
-            return self._selenium_eyes._debug_screenshot_provided
+        return self._selenium_eyes.save_debug_screenshots
 
-    @_debug_screenshot_provided.setter
-    def _debug_screenshot_provided(self, save):
+    @save_debug_screenshots.setter
+    def save_debug_screenshots(self, save):
         # type: (bool) -> None
-        if not self._is_visual_grid_eyes:
-            self._selenium_eyes._debug_screenshot_provided = save
+        """If True, will save all screenshots to local directory."""
+        self._selenium_eyes.save_debug_screenshots = save
+
+    @property
+    def debug_screenshots_provider(self):
+        return self._selenium_eyes.debug_screenshots_provider
+
+    @property
+    def debug_screenshots_path(self):
+        # type: () -> Optional[Text]
+        """The path where you save the debug screenshots."""
+        return self._selenium_eyes.debug_screenshots_path
+
+    @debug_screenshots_path.setter
+    def debug_screenshots_path(self, path_to_save):
+        # type: (Text) -> None
+        """The path where you want to save the debug screenshots."""
+        self._selenium_eyes.debug_screenshots_path = path_to_save
+
+    @property
+    def debug_screenshots_prefix(self):
+        # type: () -> Optional[Text]
+        """The prefix for the screenshots' names."""
+        return self._selenium_eyes.debug_screenshots_prefix
+
+    @debug_screenshots_prefix.setter
+    def debug_screenshots_prefix(self, prefix):
+        # type: (Text) -> None
+        """The prefix for the screenshots' names."""
+        self._selenium_eyes.debug_screenshots_prefix = prefix
 
     @position_provider.setter
     def position_provider(self, provider):
@@ -209,8 +249,7 @@ class Eyes(EyesConfigurationMixin):
         """
         Gets position provider.
         """
-        if not self._is_visual_grid_eyes:
-            self._selenium_eyes.position_provider = provider
+        self._selenium_eyes.position_provider = provider
 
     @property
     def cut_provider(self):
@@ -227,9 +266,6 @@ class Eyes(EyesConfigurationMixin):
         # type: (Union[FixedCutProvider,UnscaledFixedCutProvider,NullCutProvider])->None
         """
         Manually set the the sizes to cut from an image before it's validated.
-
-        :param provider:
-        :return:
         """
         if not self._is_visual_grid_eyes:
             self._selenium_eyes.cut_provider = cutprovider
@@ -476,6 +512,13 @@ class Eyes(EyesConfigurationMixin):
         if viewport_size:
             self.configure.viewport_size = viewport_size  # type: ignore
 
+        argument_guard.not_none(
+            self.configure.app_name, ValueError("app_name is required")
+        )
+        argument_guard.not_none(
+            self.configure.test_name, ValueError("test_name is required")
+        )
+
         self._init_driver(driver)
         self._init_locator_provider()
         if self._is_visual_grid_eyes:
