@@ -796,7 +796,7 @@ class SeleniumEyes(EyesBase):
         origin_provider = ScrollPositionProvider(self.driver, scroll_root_element)
         return FullPageCaptureAlgorithm(
             self.configure.wait_before_screenshots,
-            self._debug_screenshot_provider,
+            self._debug_screenshots_provider,
             self._screenshot_factory,
             origin_provider,
             scale_provider,
@@ -849,6 +849,16 @@ class SeleniumEyes(EyesBase):
 
         return self._last_screenshot
 
+    def _crop_if_needed(self, image):
+        r_info = self.server_connector.render_info()
+        if r_info.max_image_height is None or r_info.max_image_area is None:
+            return image
+        image = image_utils.crop_to_specific_size_if_needed(
+            image, r_info.max_image_height, r_info.max_image_area
+        )
+        self._debug_screenshots_provider.save(image, "final")
+        return image
+
     def _entire_element_screenshot(self, scale_provider):
         # type: (ScaleProvider) -> EyesWebDriverScreenshot
         logger.info("Entire element screenshot requested")
@@ -866,6 +876,7 @@ class SeleniumEyes(EyesBase):
         image = algo.get_stitched_region(
             self._region_to_check, self._full_region_to_check, elem_position_provider
         )
+        image = self._crop_if_needed(image)
         return EyesWebDriverScreenshot.create_entire_frame(
             self._driver, image, RectangleSize.from_(image)
         )
@@ -900,7 +911,7 @@ class SeleniumEyes(EyesBase):
             image = algo.get_stitched_region(
                 region, Region.EMPTY(), self.position_provider
             )
-
+            image = self._crop_if_needed(image)
             return EyesWebDriverScreenshot.create_full_page(
                 self._driver, image, original_frame_position
             )
@@ -919,17 +930,18 @@ class SeleniumEyes(EyesBase):
 
     def get_scaled_cropped_viewport_image(self, scale_provider):
         image = self._image_provider.get_image()
-        self._debug_screenshot_provider.save(image, "original")
+        self._debug_screenshots_provider.save(image, "original")
         scale_provider.update_scale_ratio(image.width)
         pixel_ratio = 1 / scale_provider.scale_ratio
         if pixel_ratio != 1.0:
             logger.info("Scaling")
             image = image_utils.scale_image(image, 1.0 / pixel_ratio)
-            self._debug_screenshot_provider.save(image, "scaled")
+            self._debug_screenshots_provider.save(image, "scaled")
         if not isinstance(self.cut_provider, NullCutProvider):
             logger.info("Cutting")
             image = self.cut_provider.cut(image)
-            self._debug_screenshot_provider.save(image, "cutted")
+            self._debug_screenshots_provider.save(image, "cutted")
+        image = self._crop_if_needed(image)
         return image
 
     def _get_viewport_scroll_bounds(self):
