@@ -37,17 +37,6 @@ def to_float(val):
         return -1
 
 
-@attr.s
-class UserAgent(object):
-    os = attr.ib()
-    os_major_version = attr.ib(converter=to_float)
-    os_minor_version = attr.ib(converter=to_float)
-    browser = attr.ib()
-    browser_major_version = attr.ib(converter=to_float)
-    browser_minor_version = attr.ib(converter=to_float)
-    origin_ua_string = attr.ib()
-
-
 class BrowserNames(Enum):
     Unknown = "Unknown"
     Edge = "Edge"
@@ -68,3 +57,22 @@ class OSNames(Enum):
     ChromeOS = "ChromeOS"
     Android = "Android"
     Linux = "Linux"
+
+
+@attr.s
+class UserAgent(object):
+    os = attr.ib()
+    os_major_version = attr.ib(converter=to_float)
+    os_minor_version = attr.ib(converter=to_float)
+    browser = attr.ib()
+    browser_major_version = attr.ib(converter=to_float)
+    browser_minor_version = attr.ib(converter=to_float)
+    origin_ua_string = attr.ib()
+
+    @property
+    def is_internet_explorer(self):
+        # type: () -> bool
+        return bool(
+            self.browser == BrowserNames.IE
+            or (self.browser == BrowserNames.Edge and self.browser_major_version <= 18)
+        )
