@@ -1,7 +1,6 @@
 import typing
 from functools import partial
 from itertools import chain
-from threading import Lock
 import attr
 
 from applitools.common import (
@@ -18,12 +17,12 @@ from applitools.common import (
 from applitools.common.utils import datetime_utils, apply_base_url
 from applitools.common.utils.converters import str2bool
 from applitools.common.utils.general_utils import get_env_with_prefix
-from applitools.selenium import parsers
+from applitools.selenium.parsers import collect_urls_from_
 
 from .vg_task import VGTask
 
 if typing.TYPE_CHECKING:
-    from typing import Callable, Dict, Any, Text, List, Optional
+    from typing import Callable, Dict, Any, Text, List, Optional, NoReturn
     from applitools.common import RenderStatusResults, Region, RenderingInfo
     from applitools.selenium.visual_grid import (
         RunningTest,
@@ -61,7 +60,7 @@ class RenderTask(VGTask):
     def __attrs_post_init__(self):
         # type: () -> None
         self.func_to_run = self.perform  # type: Callable
-        self.request_resources = {}  # type: Dict[Text, VGResource]
+        self.full_request_resources = {}  # type: Dict[Text, VGResource]
 
     def perform(self):  # noqa
         # type: () -> List[RenderStatusResults]
@@ -73,7 +72,7 @@ class RenderTask(VGTask):
                     url, running_render.render_id
                 )
             )
-            resource = self.request_resources.get(url)
+            resource = self.full_request_resources.get(url)
             self.eyes_connector.render_put_resource(running_render, resource)
             return resource
 
@@ -113,9 +112,9 @@ class RenderTask(VGTask):
                 dom_resource = requests[i].dom.resource
 
                 if self.is_force_put_needed and not already_force_putted:
-                    for url in self.request_resources:
+                    for url in self.full_request_resources:
                         self.put_cache.fetch_and_store(
-                            url, get_and_put_resource_wtih_render
+                            url, get_and_put_resource_wtih_render, force=True
                         )
                     already_force_putted = True
 
@@ -141,9 +140,9 @@ class RenderTask(VGTask):
 
     def prepare_data_for_rg(self, data):
         # type: (Dict) -> List[RenderRequest]
-        self.request_resources = {}
+        self.full_request_resources = {}
         dom = self.parse_frame_dom_resources(data)
-        return self.prepare_rg_requests(dom, self.request_resources)
+        return self.prepare_rg_requests(dom, self.full_request_resources)
 
     def prepare_rg_requests(self, dom, request_resources):
         # type: (RGridDom, Dict) -> List[RenderRequest]
@@ -191,33 +190,40 @@ class RenderTask(VGTask):
 
     def parse_frame_dom_resources(self, data):  # noqa
         # type: (Dict) -> RGridDom
-        logger.debug("parse_frame_dom_resources() call")
         base_url = data["url"]
         resource_urls = data.get("resourceUrls", [])
         all_blobs = data.get("blobs", [])
         frames = data.get("frames", [])
+        logger.debug(
+            """
+        parse_frame_dom_resources() call
+
+        base_url: {base_url}
+        count blobs: {blobs_num}
+        count resource urls: {resource_urls_num}
+        count frames: {frames_num}
+
+        """.format(
+                base_url=base_url,
+                blobs_num=len(all_blobs),
+                resource_urls_num=len(resource_urls),
+                frames_num=len(frames),
+            )
+        )
+        frame_request_resources = {}
         discovered_resources_urls = set()
-        discovered_resources_lock = Lock()
 
         def handle_resources(content_type, content, resource_url):
+            # type: (Optional[Text], bytes, Text) -> NoReturn
             logger.debug(
                 "handle_resources({0}, {1}) call".format(content_type, resource_url)
             )
             if not content_type:
                 logger.debug("content_type is empty. Skip handling of resources")
                 return
-            urls_from_css, urls_from_svg = [], []
-            if content_type.startswith("text/css"):
-                urls_from_css = parsers.get_urls_from_css_resource(content)
-            if content_type.startswith("image/svg"):
-                urls_from_svg = parsers.get_urls_from_svg_resource(content)
-            for discovered_url in urls_from_css + urls_from_svg:
-                if discovered_url.startswith("data:") or discovered_url.startswith("#"):
-                    # resource already in blob or not relevant
-                    continue
-                target_url = apply_base_url(discovered_url, base_url, resource_url)
-                with discovered_resources_lock:
-                    discovered_resources_urls.add(target_url)
+            for url in collect_urls_from_(content_type, content):
+                target_url = apply_base_url(url, base_url, resource_url)
+                discovered_resources_urls.add(target_url)
 
         def get_resource(link):
             # type: (Text) -> VGResource
@@ -227,7 +233,7 @@ class RenderTask(VGTask):
 
         for f_data in frames:
             f_data["url"] = apply_base_url(f_data["url"], base_url)
-            self.request_resources[f_data["url"]] = self.parse_frame_dom_resources(
+            frame_request_resources[f_data["url"]] = self.parse_frame_dom_resources(
                 f_data
             ).resource
 
@@ -235,7 +241,7 @@ class RenderTask(VGTask):
             resource = VGResource.from_blob(blob, on_created=handle_resources)
             if resource.url.rstrip("#") == base_url:
                 continue
-            self.request_resources[resource.url] = resource
+            frame_request_resources[resource.url] = resource
 
         for r_url in set(resource_urls).union(discovered_resources_urls):
             self.resource_cache.fetch_and_store(r_url, get_resource)
@@ -250,9 +256,10 @@ class RenderTask(VGTask):
             if val is None:
                 logger.debug("No response for {}".format(r_url))
                 continue
-            self.request_resources[r_url] = self.resource_cache[r_url]
+            frame_request_resources[r_url] = val
+        self.full_request_resources.update(frame_request_resources)
         return RGridDom(
-            url=base_url, dom_nodes=data["cdt"], resources=self.request_resources
+            url=base_url, dom_nodes=data["cdt"], resources=frame_request_resources
         )
 
     def poll_render_status(self, requests):
