@@ -1,8 +1,7 @@
 import json
-import threading
 import typing
 import uuid
-from collections import OrderedDict
+from copy import copy
 
 import attr
 
@@ -17,7 +16,7 @@ from applitools.common.ultrafastgrid import (
     VisualGridSelector,
     DesktopBrowserInfo,
 )
-from applitools.core import CheckSettings, GetRegion
+from applitools.core import CheckSettings, GetRegion, ServerConnector
 from applitools.selenium import __version__, eyes_selenium_utils, resource
 from applitools.selenium.fluent import SeleniumCheckSettings
 
@@ -53,6 +52,7 @@ return '/' + xpath;"""
 
 
 PROCESS_RESOURCES = resource.get_resource("processPageAndSerializePoll.js")
+PROCESS_RESOURCES_FOR_IE = resource.get_resource("processPageAndSerializePollForIE.js")
 DOM_EXTRACTION_TIMEOUT = 5 * 60 * 1000
 
 
@@ -82,6 +82,7 @@ class VisualGridEyes(object):
         self.vg_manager = runner  # type: VisualGridRunner
         self.test_list = []  # type: List[RunningTest]
         self._test_uuid = None
+        self.server_connector = None  # type: Optional[ServerConnector]
 
     @property
     def is_open(self):
@@ -120,19 +121,19 @@ class VisualGridEyes(object):
     def open(self, driver):
         # type: (EyesWebDriver) -> EyesWebDriver
         self._test_uuid = uuid.uuid4()
-        logger.open_()
         argument_guard.not_none(driver)
         logger.debug("VisualGridEyes.open(%s)" % self.configure)
 
         self._driver = driver
         self._set_viewport_size()
 
-        ua_string = self._driver.execute_script("return navigator.userAgent").replace(
-            "useragent:", ""
-        )
         for b_info in self.configure.browsers_info:
             test = RunningTest(
-                self._create_vgeyes_connector(b_info, ua_string), self.configure, b_info
+                self._create_vgeyes_connector(
+                    b_info, self._driver.user_agent.origin_ua_string
+                ),
+                self.configure.clone(),
+                b_info,
             )
             test.on_results_received(self.vg_manager.aggregate_result)
             test.test_uuid = self._test_uuid
@@ -144,11 +145,26 @@ class VisualGridEyes(object):
 
     def get_script_result(self):
         # type: () -> Dict
+        logger.debug("get_script_result()")
+        skip_resources = json.dumps(
+            {"skipResources": list(copy(self.vg_manager.resource_cache.keys()))}
+        )
+        process_resources = (
+            PROCESS_RESOURCES
+            + "return __processPageAndSerializePoll(document, {});".format(
+                skip_resources
+            )
+        )
+        if self.driver.user_agent.is_internet_explorer:
+            process_resources = (
+                PROCESS_RESOURCES_FOR_IE
+                + "return __processPageAndSerializePollForIE(document, {});".format(
+                    skip_resources
+                )
+            )
+
         return eyes_selenium_utils.get_dom_script_result(
-            self.driver,
-            DOM_EXTRACTION_TIMEOUT,
-            "VG_StopWatch",
-            PROCESS_RESOURCES + "return __processPageAndSerializePoll();",
+            self.driver, DOM_EXTRACTION_TIMEOUT, "VG_StopWatch", process_resources
         )
 
     def check(self, name, check_settings):
@@ -251,7 +267,11 @@ class VisualGridEyes(object):
     def _create_vgeyes_connector(self, b_info, ua_string):
         # type: (RenderBrowserInfo, Text) -> EyesConnector
         vgeyes_connector = EyesConnector(
-            b_info, self.configure.clone(), ua_string, self.rendering_info
+            b_info,
+            self.configure.clone(),
+            ua_string,
+            self.rendering_info,
+            self.server_connector,
         )
         if self.rendering_info is None:
             self.rendering_info = vgeyes_connector.render_info()
